@@ -1,4 +1,3 @@
-from limber.cli import cli_parser
 import click
 from dotenv import load_dotenv
 import os
@@ -6,7 +5,7 @@ import yaml
 import subprocess
 import json
 from pathlib import Path
-from cli.generate_terraform import terraform
+from .cli.generate_terraform import terraform
 load_dotenv()
 
 @click.group()
